@@ -16,14 +16,25 @@
    
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-     $Id: discid.h 8219 2006-07-19 15:06:02Z matt $
+     $Id: discid.h 9569 2007-10-26 22:04:08Z robert $
 
 --------------------------------------------------------------------------- */
 #ifndef MUSICBRAINZ_DISC_ID_H
 #define MUSICBRAINZ_DISC_ID_H
 
+#ifdef WIN32
+#	ifdef libdiscid_EXPORTS
+#		define LIBDISCID_API __declspec(dllexport)
+#	else
+#		define LIBDISCID_API __declspec(dllimport)
+#	endif
+#else
+#	define LIBDISCID_API
+#endif
+
+
 
 #ifdef __cplusplus
   extern "C" {
@@ -63,7 +74,7 @@
  * libdiscid provides a pkg-config script that returns the necessary compiler and linker flags, as well as the
  * version number.  To build a small sample program one would use:
  *
- * <tt>gcc libdiscid-test.c `pkg-config --cflags --libs` -o libdiscid-test</tt>
+ * <tt>gcc libdiscid-test.c `pkg-config libdiscid --cflags --libs` -o libdiscid-test</tt>
  *
  * \section Contact
  *
@@ -86,11 +97,11 @@ typedef void *DiscId;
  * Return a handle for a new DiscId object.
  *
  * If no memory could be allocated, NULL is returned. Don't use the created
- * DiscId object before calling discid_read().
+ * DiscId object before calling discid_read() or discid_put().
  *
  * @return a DiscId object, or NULL.
  */
-DiscId *discid_new();
+LIBDISCID_API DiscId *discid_new();
 
 
 /**
@@ -98,7 +109,7 @@ DiscId *discid_new();
  *
  * @param d a DiscId object created by discid_new()
  */
-void discid_free(DiscId *d);
+LIBDISCID_API void discid_free(DiscId *d);
 
 
 /**
@@ -118,7 +129,7 @@ void discid_free(DiscId *d);
  * @param device an operating system dependent device identifier, or NULL
  * @return true if successful, or false on error.
  */
-int discid_read(DiscId *d, const char *device);
+LIBDISCID_API int discid_read(DiscId *d, const char *device);
 
 
 /**
@@ -134,7 +145,7 @@ int discid_read(DiscId *d, const char *device);
  *
  * The offsets parameter points to an array which contains the track offsets
  * for each track. The first element, offsets[0], is the leadout track. It
- * must contain the total numbers of sectors on the disc.
+ * must contain the total number of sectors on the disc.
  *
  * @param d a DiscID object created by discid_new()
  * @param first the number of the first audio track on disc (usually one)
@@ -142,7 +153,7 @@ int discid_read(DiscId *d, const char *device);
  * @param offsets a pointer to an array of 100 track offsets
  * @return true if the given data was valid, and false on error
  */
-int discid_put(DiscId *d, int first, int last, int *offsets);
+LIBDISCID_API int discid_put(DiscId *d, int first, int last, int *offsets);
 
 
 /**
@@ -154,7 +165,7 @@ int discid_put(DiscId *d, int first, int last, int *offsets);
  * @param d a DiscId object created by discid_new()
  * @return a string describing the error that occurred
  */
-char *discid_get_error_msg(DiscId *d);
+LIBDISCID_API char *discid_get_error_msg(DiscId *d);
 
 
 /**
@@ -165,7 +176,7 @@ char *discid_get_error_msg(DiscId *d);
  * @param d a DiscId object created by discid_new()
  * @return a string containing a MusicBrainz DiscID
  */
-char *discid_get_id(DiscId *d);
+LIBDISCID_API char *discid_get_id(DiscId *d);
 
 
 /**
@@ -176,7 +187,7 @@ char *discid_get_id(DiscId *d);
  * @param d a DiscId object created by discid_new()
  * @return a string containing a FreeDB DiscID
  */
-char *discid_get_freedb_id(DiscId *d);
+LIBDISCID_API char *discid_get_freedb_id(DiscId *d);
 
 
 /**
@@ -191,15 +202,27 @@ char *discid_get_freedb_id(DiscId *d);
  * @param d a DiscId object created by discid_new()
  * @return a string containing an URL
  */
-char *discid_get_submission_url(DiscId *d);
+LIBDISCID_API char *discid_get_submission_url(DiscId *d);
 
+/**
+ * Return an URL for retrieving CD information from MusicBrainz' web service
+ *
+ * The URL provides the CD information in XML. 
+ * See http://musicbrainz.org/development/mmd for details.
+ *
+ * The returned string is only valid as long as the DiscId object exists.
+ *
+ * @param d a DiscId object created by discid_new()
+ * @return a string containing an URL
+ */
+LIBDISCID_API char *discid_get_webservice_url(DiscId *d);
 
 /**
  * Return the name of the default disc drive for this operating system.
  *
  * @return a string containing an operating system dependent device identifier
  */
-char *discid_get_default_device(void);
+LIBDISCID_API char *discid_get_default_device(void);
 
 
 /**
@@ -208,7 +231,7 @@ char *discid_get_default_device(void);
  * @param d a DiscId object created by discid_new()
  * @return the number of the first track
  */
-int discid_get_first_track_num(DiscId *d);
+LIBDISCID_API int discid_get_first_track_num(DiscId *d);
 
 
 /**
@@ -217,7 +240,7 @@ int discid_get_first_track_num(DiscId *d);
  * @param d a DiscId object created by discid_new()
  * @return the number of the last track
  */
-int discid_get_last_track_num(DiscId *d);
+LIBDISCID_API int discid_get_last_track_num(DiscId *d);
 
 
 /**
@@ -226,7 +249,7 @@ int discid_get_last_track_num(DiscId *d);
  * @param d a DiscId object created by discid_new()
  * @return the length of the disc in sectors
  */
-int discid_get_sectors(DiscId *d);
+LIBDISCID_API int discid_get_sectors(DiscId *d);
 
 
 /**
@@ -239,7 +262,7 @@ int discid_get_sectors(DiscId *d);
  * @param track_num the number of a track
  * @return sector offset of the specified track
  */
-int discid_get_track_offset(DiscId *d, int track_num);
+LIBDISCID_API int discid_get_track_offset(DiscId *d, int track_num);
 
 
 /**
@@ -252,7 +275,7 @@ int discid_get_track_offset(DiscId *d, int track_num);
  * @param track_num the number of a track
  * @return length of the specified track
  */
-int discid_get_track_length(DiscId *d, int track_num);
+LIBDISCID_API int discid_get_track_length(DiscId *d, int track_num);
 
 
 #ifdef __cplusplus
